==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/SplineAreaSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SplineSeriesBaseDescriptionMetadata } from "./SplineSeriesBaseDescriptionMetadata";
import { SplineAreaSeriesDescription } from "./SplineAreaSeriesDescription";
/**
 * @hidden
 */
var SplineAreaSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(SplineAreaSeriesDescriptionMetadata, _super);
    function SplineAreaSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SplineAreaSeriesDescriptionMetadata.b = function (a) {
        if (SplineAreaSeriesDescriptionMetadata.a == null) {
            SplineAreaSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            SplineAreaSeriesDescriptionMetadata.c(SplineAreaSeriesDescriptionMetadata.a);
        }
        if (a.j(SplineAreaSeriesDescriptionMetadata.a)) {
            return;
        }
        a.y(SplineAreaSeriesDescriptionMetadata.a);
    };
    SplineAreaSeriesDescriptionMetadata.c = function (a) {
        SplineSeriesBaseDescriptionMetadata.c(a);
    };
    SplineAreaSeriesDescriptionMetadata.d = function (a) {
        SplineAreaSeriesDescriptionMetadata.b(a);
        a.aa("SplineAreaSeries", function () { return new SplineAreaSeriesDescription(); });
        a.z("SplineAreaSeries", SplineAreaSeriesDescriptionMetadata.a);
    };
    SplineAreaSeriesDescriptionMetadata.$t = markType(SplineAreaSeriesDescriptionMetadata, 'SplineAreaSeriesDescriptionMetadata');
    SplineAreaSeriesDescriptionMetadata.a = null;
    return SplineAreaSeriesDescriptionMetadata;
}(Base));
export { SplineAreaSeriesDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/SplineAreaSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SplineSeriesBaseDescriptionMetadata } from "./SplineSeriesBaseDescriptionMetadata";
import { SplineAreaSeriesDescription } from "./SplineAreaSeriesDescription";
/**
 * @hidden
 */
var SplineAreaSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(SplineAreaSeriesDescriptionMetadata, _super);
    function SplineAreaSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SplineAreaSeriesDescriptionMetadata.b = function (a) {
        if (SplineAreaSeriesDescriptionMetadata.a == null) {
            SplineAreaSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            SplineAreaSeriesDescriptionMetadata.c(SplineAreaSeriesDescriptionMetadata.a);
        }
        if (a.k(SplineAreaSeriesDescriptionMetadata.a)) {
            return;
        }
        a.aa(SplineAreaSeriesDescriptionMetadata.a);
    };
    SplineAreaSeriesDescriptionMetadata.c = function (a) {
        SplineSeriesBaseDescriptionMetadata.c(a);
    };
    SplineAreaSeriesDescriptionMetadata.d = function (a) {
        SplineAreaSeriesDescriptionMetadata.b(a);
        a.ac("SplineAreaSeries", function () { return new SplineAreaSeriesDescription(); });
        a.ab("SplineAreaSeries", SplineAreaSeriesDescriptionMetadata.a);
    };
    SplineAreaSeriesDescriptionMetadata.$t = markType(SplineAreaSeriesDescriptionMetadata, 'SplineAreaSeriesDescriptionMetadata');
    SplineAreaSeriesDescriptionMetadata.a = null;
    return SplineAreaSeriesDescriptionMetadata;
}(Base));
export { SplineAreaSeriesDescriptionMetadata };
